pub struct PositionLLA {
pub lon: f64,
pub lat: f64,
pub alt: f64,
}Expand description
Represents a geodetic Position in the form of Longitude, Latitude, and Altitude This can be constructed for example from NavPosLlh and NavPvt uBlox packets.
Fields
lon: f64Longitude in degrees
lat: f64Latitude in degrees
alt: f64Altitude in meters